/*
* @license Apache-2.0
*
* Copyright (c) 2024 The Stdlib Authors.
*
* Licensed under the Apache License, Version 2.0 (the "License");
* you may not use this file except in compliance with the License.
* You may obtain a copy of the License at
*
*    http://www.apache.org/licenses/LICENSE-2.0
*
* Unless required by applicable law or agreed to in writing, software
* distributed under the License is distributed on an "AS IS" BASIS,
* WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
* See the License for the specific language governing permissions and
* limitations under the License.
*/

import base64ToUint8Array = require( './index' );


// TESTS //

// The function returns a Uint8Array (or null)...
{
	base64ToUint8Array( 'Hello World!' ); // $ExpectType Uint8Array | null
}

// The compiler throws an error if the function is provided a value other than a string...
{
	base64ToUint8Array( true ); // $ExpectError
	base64ToUint8Array( false ); // $ExpectError
	base64ToUint8Array( null ); // $ExpectError
	base64ToUint8Array( undefined ); // $ExpectError
	base64ToUint8Array( 5 ); // $ExpectError
	base64ToUint8Array( [] ); // $ExpectError
	base64ToUint8Array( {} ); // $ExpectError
	base64ToUint8Array( ( x: number ): number => x ); // $ExpectError
}

// The compiler throws an error if the function is provided insufficient arguments...
{
	base64ToUint8Array(); // $ExpectError
}
